"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = QuickSearchForm;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactIntl = require("react-intl");

var _immutable = _interopRequireDefault(require("immutable"));

var _cspaceInput = require("cspace-input");

var _searchHelpers = require("../../helpers/searchHelpers");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

const {
  QuickSearchInput
} = _cspaceInput.components;
const messages = (0, _reactIntl.defineMessages)({
  placeholder: {
    "id": "quickSearchForm.placeholder",
    "defaultMessage": "Search"
  },
  search: {
    "id": "quickSearchForm.search",
    "defaultMessage": "Search"
  }
});
const propTypes = {
  intl: _reactIntl.intlShape,
  config: _propTypes.default.shape({
    recordTypes: _propTypes.default.object
  }),
  perms: _propTypes.default.instanceOf(_immutable.default.Map),
  getAuthorityVocabCsid: _propTypes.default.func
};

function QuickSearchForm(props) {
  const {
    intl,
    config,
    perms,
    getAuthorityVocabCsid
  } = props,
        remainingProps = _objectWithoutProperties(props, ["intl", "config", "perms", "getAuthorityVocabCsid"]);

  const formatRecordTypeLabel = (name, recordTypeConfig) => intl.formatMessage(recordTypeConfig.messages.record.collectionName);

  const formatVocabularyLabel = (name, vocabularyConfig) => intl.formatMessage(vocabularyConfig.messages.name);

  return _react.default.createElement("fieldset", null, _react.default.createElement(QuickSearchInput, _extends({}, remainingProps, {
    formatRecordTypeLabel: formatRecordTypeLabel,
    formatVocabularyLabel: formatVocabularyLabel,
    placeholder: intl.formatMessage(messages.placeholder),
    recordTypes: (0, _searchHelpers.getSearchableRecordTypes)(getAuthorityVocabCsid, config, perms),
    searchButtonLabel: intl.formatMessage(messages.search)
  })));
}

QuickSearchForm.propTypes = propTypes;